;; put here instructions to compile each pack in dist-packages folder
; unittest pack
(tl-load "unittest")
(compile-file "unittest.lisp")
; copy pack
(tl-load "copy")
(compile-file "copy.lisp")
; Clisp integration module
(ext:without-package-lock ("SYSTEM") (tl-load "clisp-pluggin") (compile-file "clisp-pluggin.lisp"))
